use strict;
use Test::More 0.98;

use_ok $_ for qw(
    WebService::Qiita::V2
    WebService::Qiita::V2::Client
    WebService::Qiita::V2::Client::Base
    WebService::Qiita::V2::Client::Methods
);

done_testing;

